#!/bin/sh
# configversion: c7034e3e9ad35e76c3b3a5e0a461adf1
# SPDX-License-Identifier: AGPL-3.0-only
# Copyright 2022 Sxmo Contributors

# This script is called prior to suspending

# include common definitions
# shellcheck source=scripts/core/sxmo_common.sh
. sxmo_common.sh

sxmo_daemons.sh stop periodic_blink

pkill clickclack
sxmo_keyboard.sh close
pkill -INT mpv #if any audio/video is playing, kill it (it might stutter otherwise)

case "$SXMO_WM" in
	dwm)
		sxmo_dmenu.sh close
		;;
esac
